@@ -425,7 +425,10 @@ class BlockDialog(QtGui.QDialog):
 		if 'wild' in params:
 			self.ui.wildness.setValue(params["wild"])
 		if 'swing' in params:
-			self.ui.swing.setChecked(True)
+			if params["swing"]:
+				self.ui.swing.setCurrentIndex(2)
+			else:
+				self.ui.swing.setCurrentIndex(1)
 		if 'key' in params:
 			self.ui.key.setCurrentIndex(combo_index_by_text(self.ui.key, params["key"]))
 		if 'resolution' in params:
@@ -443,7 +446,7 @@ class BlockDialog(QtGui.QDialog):
 		key = str(self.ui.key.currentText())
 		wild = self.ui.wildness.value()
 		duration = self.ui.duration.value()
-		swing = self.ui.swing.isChecked()
+		swing = self.ui.swing.currentIndex()
 
 		if bpm != 0:
 			res += "bpm:%d " % bpm
@@ -452,8 +455,8 @@ class BlockDialog(QtGui.QDialog):
 		if duration != 0:
 			res += "duration:%d " % duration
 		
-		if swing:
-			res += "swing "
+		if swing > 0:
+			res += "swing:%d " % (swing - 1)
 		if resolution != "From movement":
 			res += "resolution:%s " % resolution
 		if key != "From movement":
